﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Media;
using Infragistics.Controls.Charts;

namespace GenerateChart
{
    public static class Chart1
    {
        public static XamDataChart GetChart()
        {
            SimpleDataCollection thisCollection = new SimpleDataCollection(0, 15);

            var chart = new XamDataChart();
            chart.Padding = new Thickness(35, 0, 40, 0);

            LinearGradientBrush lgb = new LinearGradientBrush
            {
                StartPoint = new Point(0, 1),
                EndPoint = new Point(0, 0)
            };
            GradientStop lightGreyGS = new GradientStop
            {
                Color = Colors.LightGray,
                Offset = 0.0
            };
            GradientStop whiteGS = new GradientStop
            {
                Color = Colors.White,
                Offset = 1.0
            };
            lgb.GradientStops.Add(lightGreyGS);
            lgb.GradientStops.Add(whiteGS);
            chart.PlotAreaBackground = lgb;

            var xAxis = new CategoryDateTimeXAxis();

            xAxis.MinorInterval = new TimeSpan(0, 2, 0, 0, 0);
            xAxis.MinorStrokeThickness = 1;
            xAxis.MinorStroke = Brushes.White;
            xAxis.MajorStroke = Brushes.Black;
            xAxis.Interval = new TimeSpan(1, 0, 0, 0, 0);
            xAxis.MajorStrokeThickness = 2;

            var yAxis = new NumericYAxis
            {
                LabelSettings = new AxisLabelSettings
                {
                    Margin = new Thickness(10)
                },
                MinimumValue = 0,
                Interval = 5,
                MaximumValue = 20
            };

            xAxis.ItemsSource = thisCollection;
            xAxis.DateTimeMemberPath = "Label";
            xAxis.Label = "{Label: dd-MMM-yy HH:ss}";


            chart.Axes.Add(xAxis);
            chart.Axes.Add(yAxis);

            var series = new LineSeries
            {
                ValueMemberPath = "Value",
                ItemsSource = thisCollection,
                XAxis = xAxis,
                YAxis = yAxis,
                Brush = System.Windows.Media.Brushes.Blue,
                MarkerBrush = System.Windows.Media.Brushes.Blue,
                MarkerType = MarkerType.Square,
                ToolTip = GetTooltip()
            };


            chart.Series.Add(series);

            var sync1 = new SyncSettings();
            sync1.SyncChannel = "syncGroup1";
            sync1.SynchronizeHorizontally = true;
            SyncManager.SetSyncSettings(chart, sync1);

            return chart;
        }

        public static ContentControl GetTooltip()
        {
            ContentControl cc = new ContentControl();

            StackPanel ParentStack = new StackPanel();

            StackPanel YStack = new StackPanel() { Orientation = Orientation.Horizontal };
            TextBlock yValue = new TextBlock();
            yValue.SetBinding(TextBlock.TextProperty, new Binding("Item.Label"));
            YStack.Children.Add(yValue);

            ParentStack.Children.Add(YStack);

            cc.Content = ParentStack;

            return cc;
        }

    }
}
